PhysicsAnimatedContainer class

A widget that displays multiple physics objects in a container.

Inheritance

Constructors

PhysicsAnimatedContainer({Key? key, required PhysicsAnimationController controller, required Widget objectBuilder(BuildContext context, PhysicsObject object), BoxDecoration? decoration, BoxConstraints? constraints, bool autoStart = true, bool showDebugInfo = false})
Creates a new physics animated container.
const

Properties

autoStart bool
Whether to automatically start the animation
final
constraints BoxConstraints?
Container constraints
final
controller PhysicsAnimationController
The physics animation controller
final
decoration BoxDecoration?
Container decoration
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
objectBuilder Widget Function(BuildContext context, PhysicsObject object)
Builder function to create widgets for physics objects
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDebugInfo bool
Whether to show physics debug information
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<PhysicsAnimatedContainer>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited